@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based objectqueue package
 
-$Id: interfaces.py 49894 2008-02-02 15:43:40Z cray $
+$Id: interfaces.py 50793 2008-02-21 10:53:53Z cray $
 """
 __author__  = "Yegor Shershnev & Elena Antusheva, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49894 $"
+__version__ = "$Revision: 50793 $"
  
 from zope.interface import Interface
 
@@ -36,14 +36,14 @@ class IObjectQueueDataAdd(Interface) :
     maxlen = Int(
         title=u"Maximum Length",
         description=u"maximum length of queue",
-        default=10,
+        default=20,
         )
 
     style = Choice(
         title=u'Style',
         description=u"Style of queue",
         vocabulary = SimpleVocabulary.fromValues([u"fifo", u"lifo"]),
-        default=u"lifo",
+        default=u"fifo",
         required=True,
         )
     
@@ -53,7 +53,7 @@ class IObjectQueueDataAdd(Interface) :
         title=u'Order',
         description=u"Order",
         vocabulary = SimpleVocabulary.fromValues([u"straight", u"reverse"]),
-        default=u"reverse",
+        default=u"straight",
         required=True,
         )
 
@@ -85,26 +85,30 @@ class IObjectQueueData(IObjectQueueDataAdd) :
         )
 
 
-
 class IObjectQueueAvailable(Interface) :
     pass
-    
+
+
 class IObjectQueueAnnotable(IObjectQueueAvailable) :
     pass
-        
+
+
 class IObjectQueueUtilitable(IObjectQueueAvailable) :
     pass
-            
+
+
 class IObjectQueue(IObjectQueueHandle, IObjectQueueData, IReadContainer, IObjectQueueAnnotable):
     pass
 
 
 class IObjectQueueAnnotation(IObjectQueue) :
     pass
-    
+
+
 class IObjectQueueUtility(IObjectQueue) :
     pass
-    
+
+
 class IObjectQueueAll(Interface) :
     """ Enumerator for all ObjectQueue Utilities """
 
@@ -114,6 +118,7 @@ class IObjectQueueAll(Interface) :
     def __iter__() :
         pass
 
+
 class IObjectQueueUtilities(Interface) :
     """ Enumerator for all ObjectQueue Utilities """
 
@@ -128,4 +133,3 @@ class IObjectQueueAble(Interface) :
     """ Interface of objects that can be queue"""
  
 objectqueuekey="ng.app.objectqueue.objectqueue.ObjectQueue"
-
