@@ -1,17 +1,18 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""QuotaAdapter class for the Zope 3 based ng.app.quota.quotaannotation package
+"""QuotaAdapter class for the Zope 3 based ng.app.objectqueue package
 
-$Id: objectqueueutilities.py 49894 2008-02-02 15:43:40Z cray $
+$Id: objectqueueutilities.py 50793 2008-02-21 10:53:53Z cray $
 """
 __author__  = "Yegor Shershnev, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49894 $"
+__version__ = "$Revision: 50793 $"
 
 
 from zope.component import getUtilitiesFor
 from interfaces import IQuota
 
+
 class QuotaAdapter(object) :
 
     def __init__(self,context) :
@@ -29,4 +30,3 @@ class QuotaAdapter(object) :
     def handleRemoved(self,ob): 
         for quota in self.quotas :
             quota.handleRemoved(ob)
-
